pub struct Role { /* private fields */ }Expand description
Access role with its allowed statements.
Implementations
Sourceimpl Role
impl Role
Authorize a request requiring every requested resource to pass.
Authorize a request requiring at least one requested resource to pass.
Authorize a request against this role’s statements.
Sourceimpl Role
impl Role
Sourcepub fn statements(&self) -> &Statements
pub fn statements(&self) -> &Statements
Return the role’s allowed statements.