Custom session plugin.
Structs
- Custom
Session Context - Request context available to custom session handlers.
- Custom
Session Input - Session payload passed to the custom session handler.
- Custom
Session Options - Options for the custom session plugin.
Constants
Functions
- custom_
session - Create a custom session plugin with default options.
- custom_
session_ with_ context - Create a custom session plugin whose handler can inspect request context.
- custom_
session_ with_ context_ and_ options - Create a custom session plugin with options and request-aware handler.
- custom_
session_ with_ options - Create a custom session plugin.