Module custom_session

Module custom_session 

Custom session plugin.

Structs

CustomSessionContext
Request context available to custom session handlers.
CustomSessionInput
Session payload passed to the custom session handler.
CustomSessionOptions
Options for the custom session plugin.

Constants

UPSTREAM_PLUGIN_ID

Functions

custom_session
Create a custom session plugin with default options.
custom_session_with_context
Create a custom session plugin whose handler can inspect request context.
custom_session_with_context_and_options
Create a custom session plugin with options and request-aware handler.
custom_session_with_options
Create a custom session plugin.

Type Aliases

CustomSessionFuture